calculate_cep

Function calculate_cep 

pub fn calculate_cep(wind_drift_values: &[f64], drop_values: &[f64]) -> f64
Calculate CEP (Circular Error Probable) from impact points

CEP is the radius of a circle centered at the mean point of impact, within which 50% of the shots fall. It’s a standard measure of precision.